#include "window.h"

Window::Window(int width, int height, int windowFps, int windowFlags)
{
	if (SDL_Init(SDL_INIT_VIDEO) < 0)
	{
		cout << "Couldn't initialize SDL: " << SDL_GetError() << endl;
		exit(1);
	}

	IMG_Init(IMG_INIT_PNG | IMG_INIT_JPG);

	this->window = SDL_CreateWindow("Spirit", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, width, height, windowFlags);
    SDL_SetWindowResizable(this->window, SDL_TRUE);
    
	if (!this->window)
	{
        cout << "Failed to open window: " << SDL_GetError() << endl;
		exit(1);
	}
    
	SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "linear");

	this->renderer = SDL_CreateRenderer(this->window, -1, SDL_RENDERER_ACCELERATED);

	if (!this->renderer)
	{
        cout << "Failed to create renderer: " << SDL_GetError() << endl;
		exit(1);
	}

	this->spritesheet = IMG_LoadTexture(this->renderer, "./spritesheet.png");
	SDL_SetTextureScaleMode(this->spritesheet, SDL_ScaleModeNearest);

	this->windowDelay = 1000/windowFps;
}

void Window::clear()
{
    if (SDL_SetRenderDrawColor(this->renderer, 0, 0, 0, 255))
        cout << "\n";
    SDL_RenderClear(this->renderer);
}

void Window::draw(GameObject &object)
{
	Frame frame = object.frame();

	SDL_RenderCopy(this->renderer, this->spritesheet, &(frame.srcrect), &(frame.dstrect));
}

void Window::update()
{
    SDL_RenderPresent(this->renderer);
	SDL_Delay(this->windowDelay);
}

void Window::quit()
{
    SDL_Quit();
    exit(0);
}